local Gladius = Gladius
local self = Gladius
local LSM = LibStub("LibSharedMedia-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("Gladius", true)
LSM:Register("statusbar", "Minimalist", "Interface\\Addons\\Gladius\\images\\Minimalist")

local defaults = {
	profile = {
	    x=0,
		y=0,
		frameScale = 1,
		barWidth=150,
		barHeight=25,
		manaBarHeight=15,
		castBarHeight=12,
		padding=5,
		frameColor = {r = 0, g = 0, b = 0, a = .3},
		manaColor = {r = .18, g = .44, b = .75, a = 1},
		energyColor = {r = 1, g = 1, b = 0, a = 1},
		rageColor = {r = 1, g = 0, b = 0, a = 1},
		selectedFrameColor = {r = 1, g = .7, b = 0, a = 1},
		castBarColor = {r = 1, g = 1, b = 0, a = 1},
		manaFontColor = {r = 2.55, g = 2.55, b = 2.55, a = 1},
		healthFontColor = {r = 2.55, g = 2.55, b = 2.55, a = 1},
		castBarFontColor = {r = 2.55, g = 2.55, b = 2.55, a = 1},
		auraFontColor = {r = 0, g = 1, b = 0, a = 1},
		healthFontSize = 12,
		manaFontSize = 10,
		castBarFontSize = 9,
		auraFontSize = 16,
		barTexture = "Minimalist",
		barBottomMargin = 8,
		highlight = true,
		selectedBorder = true,
		manaDefault = false,
		energyDefault = false,
		rageDefalt = false,
		locked=false,
		manaText=true,
		classText=true,
		castBar=true,
		powerBar=true,
		classIcon=true,
		auras=true,
		frameResize=true,
	}
}

--LSM statusbars
statusbars = {}

for _, name in pairs(LSM:List(LSM.MediaType.STATUSBAR)) do
		statusbars[name] = name
end

local slashHandler = function(option)
	if option == "ui" or option == "config" or option == "options" then
		Gladius:ShowOptions()
	elseif option == "test1" then
		self:ToggleFrame(1)
	elseif option == "test2" then
		self:ToggleFrame(2)
	elseif option == "test3" then
		self:ToggleFrame(3)
	elseif option == "test4" then
		self:ToggleFrame(4)
	elseif option == "test5" or option == "test" then
		self:ToggleFrame(5)
	elseif option == "hide" then
		self:HideFrame()
	else
		self:Print("Valid slash commands:")
		self:Print("/gladius ui")
		self:Print("/gladius test1-5")	
	end
end

function Gladius:ToggleFrame(i)
	self:ClearAllUnits()
	if (self.frame and self.frame:IsShown() and i == self.currentBracket) then
		self.frame:Hide()
		self:UnregisterAllEvents()
		self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
		self:RegisterEvent("PLAYER_ENTERING_WORLD", "ZONE_CHANGED_NEW_AREA")
		self.currentBracket = nil
	else
		self.currentBracket = i
		if (self.frame == nil) then
			self:CreateFrame()
		end
		self:RegisterEvent("PLAYER_TARGET_CHANGED")
		self.frame:Show()
		self:Test()
		self:UpdateFrame()
		Gladius:UpdateBindings()
	end
end

function Gladius:HideFrame()
	self.frame:Hide()
	self:UnregisterAllEvents()
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	self:RegisterEvent("PLAYER_ENTERING_WORLD", "ZONE_CHANGED_NEW_AREA")
	self.currentBracket = nil
end

local function getOption(info)
  return (info.arg and Gladius.db.profile[info.arg] or Gladius.db.profile[info[#info]])
end

local function setOption(info, value)
  local key = info.arg or info[#info]
  Gladius.db.profile[key] = value
  Gladius:UpdateFrame()
end

local function getColorOption(info)
  local key = info.arg or info[#info]
  return Gladius.db.profile[key].r, Gladius.db.profile[key].g, Gladius.db.profile[key].b, Gladius.db.profile[key].a
end

local function setColorOption(info, r, g, b, a)
  local key = info.arg or info[#info]
  Gladius.db.profile[key].r, Gladius.db.profile[key].g, Gladius.db.profile[key].b, Gladius.db.profile[key].a = r, g, b, a
  Gladius:UpdateFrame()
end

function Gladius:getDefaults()
	return defaults
end

function Gladius:SetupOptions()
	self.options = {
		type = "group",
		name = "Gladius",
		plugins = {},
		get=getOption,
		set=setOption,
		args = {
			general = {
				type="group",
				name=L["General"],
				desc=L["General settings"],
				order=1,
				args = {
					locked = {
					type="toggle",
					name=L["Lock frame"],
					desc=L["Toggle if the frame can be moved"],
					order=10,
					},
					frameResize = {
					type="toggle",
					name=L["Frame resize"],
					desc=L["If this is enabled the frame will automaticly get resized to the appropriate size every time you enter an arena"],
					order=10,
					},
					frameScale = {
						type="range",
						name=L["Frame scale"],
						desc=L["Scale of the frame"],
						min=.1,
						max=2,
						step=.1,
						order=20,
					},
					padding = {
						type="range",
						name=L["Frame padding"],
						desc=L["Padding of the frame"],
						min=0,
						max=20,
						step=1,
						order=30,
					},
					frameColor = {
						type="color",
						name=L["Frame color"],
						desc=L["Color of the frame"],
						hasAlpha=true,
						order=35,
						get=getColorOption,
						set=setColorOption,
					},
					castBar = {
						type="toggle",
						name=L["Show cast bars"],
						desc=L["Show cast bars"],
						order=40,
					},
					powerBar = {
						type="toggle",
						name=L["Show power bars"],
						desc=L["Show power bars"],
						order=50,
					},						
					manaText = {
						type="toggle",
						name=L["Show power percentage"],
						desc=L["Show mana/energy/rage percentage on the power bar"],
						disabled = function() return not self.db.profile.powerBar end,
						order=60,
					},
					classText = {
						type="toggle",
						name=L["Show race/class text"],
						desc=L["Show race/class text on the power bar"],
						disabled = function() return not self.db.profile.powerBar end,
						order=70,
					},
					highlight = {
						type="toggle",
						name=L["Highlight target"],
						desc=L["Toggle if the selected target should be highlighted"],
						order=80,
					},
					selectedBorder = {
						type="toggle",
						name=L["Show border around target"],
						desc=L["Toggle if a border should be shown around the selected target"],
						order=90,
					},
					classIcon = {
						type="toggle",
						name=L["Show class icon"],
						desc=L["Show class icon\nIMPORTANT:\nToggling this off will disable showing auras even if it is enabled"],
						order=95,
					},
					auras = {
						type="toggle",
						name=L["Show auras"],
						desc=L["Show important auras over the class icon with a timer. You can select which auras to show and their respective priorites in the auralist.lua file"],
						disabled = function() return not self.db.profile.classIcon end,						
						order=100,
					},
				},
			},
			bars = {
				type="group",
				name=L["Bars"],
				desc=L["Bar settings"],
				order=2,
				args = {
					barTexture = {
						type="select",
						name=L["Bar texture"],
						dialogControl = "LSM30_Statusbar",
						values = statusbars,
						get=function(info)
								return statusbars[Gladius.db.profile.barTexture]
							end,
						set=function(info, v)
								Gladius.db.profile.barTexture = statusbars[v]
								self:UpdateFrame()
							end,
						order=1
					},
					barWidth = {
						type="range",
						name=L["Bar width"],
						desc=L["Width of the health and power bars"],
						min=100,
						max=500,
						step=5,
						order=2,
						},
					barHeight = {
						type="range",
						name=L["Health bar height"],
						desc=L["Height of the health bars"],
						min=10,
						max=50,
						step=1,
						order=3,
					},
					manaBarHeight = {
						type="range",
						name=L["Power bar height"],
						desc=L["Height of the power bars"],
						disabled = function() return not self.db.profile.powerBar end,
						min=10,
						max=50,
						step=1,
						order=4,
					},
					castBarHeight = {
						type="range",
						name=L["Cast bar height"],
						desc=L["Height of the cast bars"],
						disabled = function() return not self.db.profile.castBar end,
						min=10,
						max=50,
						step=1,
						order=5,
					},
					barBottomMargin = {
						type="range",
						name=L["Bar bottom margin"],
						desc=L["Margin to the next bar"],
						min=0,
						max=30,
						step=1,
						order=6,
					},
					colors = {
						type="group",
						name=L["Colors"],
						desc=L["Color settings"],
						args = {
							selectedFrameColor = {
								type="color",
								name=L["Selected border color"],
								desc=L["Color of the selected targets border"],
								disabled = function() return not self.db.profile.selectedBorder end,
								get=getColorOption,
								set=setColorOption,
								hasAlpha=true,
								order=2,
							},
							manaColor = {
								type="color",
								name=L["Mana color"],
								desc=L["Color of the mana bar"],
								disabled = function() return not self.db.profile.powerBar or self.db.profile.manaDefault end,
								get=getColorOption,
								set=setColorOption,
								hasAlpha=true,
								order=3,
							},
							manaDefault = {
								type="toggle",
								name=L["Game default"],
								desc=L["Use game default mana color"],
								order=4,
							},
							energyColor = {
								type="color",
								name=L["Energy color"],
								desc=L["Color of the energy bar"],
								disabled = function() return not self.db.profile.powerBar or self.db.profile.energyDefault end,
								get=getColorOption,
								set=setColorOption,
								hasAlpha=true,
								order=5,
							},
							energyDefault = {
								type="toggle",
								name=L["Game default"],
								desc=L["Use game default energy color"],
								order=6,
							},
							rageColor = {
								type="color",
								name=L["Rage color"],
								desc=L["Color of the rage bar"],
								disabled = function() return not self.db.profile.powerBar or self.db.profile.rageDefault end,
								get=getColorOption,
								set=setColorOption,
								hasAlpha=true,
								order=7,
							},
							rageDefault = {
								type="toggle",
								name=L["Game default"],
								desc=L["Use game default rage color"],
								order=8,
							},
							castBarColor = {
								type="color",
								name=L["Cast bar color"],
								desc=L["Color of the cast bar"],
								disabled = function() return not self.db.profile.castBar end,
								get=getColorOption,
								set=setColorOption,
								hasAlpha=true,
								order=9,
							},
						},
					},
				},
			},
			fonts = {
				type="group",
				name=L["Fonts"],
				desc=L["Font settings"],
				order=3,
				args = {
					healthFontSize = {
						type="range",
						name=L["Health text size"],
						desc=L["Size of the health bar text"],
						min=1,
						max=20,
						step=1,
						order=1,
					},
					manaFontSize = {
						type="range",
						name=L["Mana text size"],
						desc=L["Size of the mana bar text"],
						disabled = function() return not self.db.profile.powerBar end,
						min=1,
						max=20,
						step=1,
						order=3,
					},						
					castBarFontSize = {
						type="range",
						name=L["Cast bar text size"],
						desc=L["Size of the cast bar text"],
						disabled = function() return not self.db.profile.castBar end,
						min=1,
						max=20,
						step=1,
						order=5,
					},
					auraFontSize = {
						type="range",
						name=L["Aura text size"],
						desc=L["Size of the aura text"],
						disabled = function() return not self.db.profile.auras end,
						min=1,
						max=20,
						step=1,
						order=10,
					},
					colors = {
						type="group",
						name=L["Colors"],
						desc=L["Color settings"],
						args = {
							healthFontColor = {
								type="color",
								name=L["Health text color"],
								desc=L["Color of the health bar text"],
								get=getColorOption,
								set=setColorOption,
								hasAlpha=true,
								order=2,
							},
							manaFontColor = {
								type="color",
								name=L["Mana text color"],
								desc=L["Color of the mana bar text"],
								disabled = function() return not self.db.profile.powerBar end,
								get=getColorOption,
								set=setColorOption,
								hasAlpha=true,
								order=4,
							},
							castBarFontColor = {
								type="color",
								name=L["Cast bar text color"],
								desc=L["Color of the cast bar text"],
								disabled = function() return not self.db.profile.castBar end,
								get=getColorOption,
								set=setColorOption,
								hasAlpha=true,
								order=6,
							},
							auraFontColor = {
								type="color",
								name=L["Aura text color"],
								desc=L["Color of the aura text"],
								disabled = function() return not self.db.profile.auras end,
								get=getColorOption,
								set=setColorOption,
								hasAlpha=true,
								order=10,
							},												
						},
					},
				},
			},
		}
	}
	
	self.options.plugins.profiles = { profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db) }
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Gladius", self.options)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Gladius", "Gladius")
	self:RegisterChatCommand("gladius", slashHandler)
	
end

function Gladius:ShowOptions()
  InterfaceOptionsFrame_OpenToCategory("Gladius")
end
